#!/bin/bash
#
#  Install script for ST Stdandard Peripherals Library
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition
# openSuSE 11.4 x86


INSTALLPATH="../Documentation"

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi
echo "installing in $INSTALLPATH ..."

#sudo apt-get libgmp3-dev libmpfr-dev

#{ InstallFuncs v0.4 - written by Gregor Rebel

function cmd() {             # CMD,[STDOUT]               display + execute given command; records log + errors
  CMD="$1"
  StdOut="$2"
  
  if [ "$StdOut" != "" ]; then
    echo "`pwd`> $CMD >>$StdOut"
    $CMD >>$StdOut
  else
    echo "`pwd`> $CMD"
    $CMD $StdOut 2>CMD.err || CMD_ERROR="$CMD"
    CMDerr=`cat CMD.err`
    if [ "$CMDerr" != "" ]; then
      CMD_ERROR="$CMD"
    fi
  fi
}
function get() {             # URL_Prefix, File, OutFile  retrieves file from URL if not already done
  URL_Prefix="$1"
  gFile="$2"
  gOutFile="$3"
  
  if [ "$gOutFile" == "" ]; then
    gOutFile=$gFile
  fi

  if [ ! -e "$gFile" ]; then
    # CMD="wget $1$2"
    # echo "`pwd`> $CMD"
    # $CMD
#pwd
    cmd "wget $URL_Prefix$gFile -O $gOutFile" 
  fi
  if [ ! -e "$gFile" ]; then
    Get_Fails="$Get_Fails $gFile"
  fi
}
function dir() {             # Directory            creates directory if missing
  Directory="$1"
  
  if [ ! -d $Directory ]; then
    mkdir $Directory
  fi
}
function untgz() {           # Dir,Archiv           unpacks .tar.gz / .tgz archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xzf $Archiv"
  fi
}
function untgj() {           # Dir,Archiv           unpacks .tar.bz2 / .tgj archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xjf $Archiv"
  fi
}
function unZIP() {           # Dir,Archiv           unpacks .zip archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then

    cmd "unzip -o $Archiv" "unzip.log"
  fi
}
function addLine() {         # File,Line            adds given line to File if not already done
  File2Add2="$1"
  Line="$2"
  
  if [ ! -e $File2Add2 ]; then
    touch $File2Add2
  fi
  AlreadyPresent=`grep "$Line" $File2Add2`
  if [ "$AlreadyPresent" == "" ]; then
    cmd "echo $Line" "$File2Add2"
#  else
#    echo "file already up2date: $File2Add2"
  fi
}
function createLink() {      # Source,Link          creates symbolic link (removes old one before)
  Source="$1"
  Link="$2"
  User="$3"
  
  if [ "$User" != "" ]; then
    sudo -u$User rm -v $Link
  else
    rm -v $Link
  fi
  
  if [ "$User" != "" ]; then
    sudo -u$User ln -vs $Source $Link
  else
    ln -vs $Source $Link
  fi
}
function makeOrig() {        # File                 creates backup file XXX_orig if not present
  bFile="$1"
  
  BakFile="${bFile}_orig"
  if [ ! -e $BakFile ]; then
    cp $bFile $BakFile
  fi
}
function replaceInFile() {   # File,Search,Replace  replaces all occurences of "$Search" in file $File by "$Replace"
    File="$1"
    Search="$2"
    Replace="$3"
    
    echo "replace $File: $Search"
    echo "     -> $File: $Replace"
    #echo "sed -e \"s|$Search|$Replace|g\" $File"
    sed -e "s|$Search|$Replace|g" $File >${File}_2
    mv -f ${File}_2 ${File}
}
function findPrefix() {      #                      loads variable Prefix either with /usr or /usr/local according to system
  if [ -e "/usr/include/math.h" ]; then
    Prefix="/usr"
  else
    Prefix="/usr/local"
  fi
}
function installPackage() {  # Name1, Name2, ...    installs all named packages via local package manager (zypper or apt-get)
  if [ -x /usr/bin/zypper ]; then
    cmd "sudo zypper install -l -y $@"
  else
    cmd "sudo apt-get install $@"
  fi
}
function add2CleanUp() {     # File, Line           adds given line to cleanup file (if not already done)
    CleanUpFile="$1"
    Line="$2"
    
    if [ ! -e "$CleanUpFile" ]; then
      echo "#!/bin/bash"  >$CleanUpFile
      echo ""            >>$CleanUpFile
      chmod +x $CleanUpFile
    fi
    addLine "$CleanUpFile" "$Line"
}

#} InstallFuncs v0.4 - written by Gregor Rebel


dir $INSTALLPATH
cd $INSTALLPATH

get http://www.st.com/mcu/files/mcu/                   1221142709.pdf  STM32_Insiders_Guide_to_the_STM32.pdf
get http://www.st.com/stonline/products/literature/an/      15531.pdf  STM32_standard_peripheral_library_V300.pdf
get http://www.st.com/stonline/products/literature/pm/      15491.pdf  STM32_Cortex-M3_Programming_Manual.pdf
get http://www.st.com/stonline/products/literature/rm/      13902.pdf  STM32_Advanced_ARM-based_32bit_MCUs.pdf
get https://silver.arm.com/download/           download.tm?pv=1073296  ARMv7-M_Architecture_Reference_Manual.pdf
get http://home.comcast.net/~mcatudal/index_fichiers/ CrossDevHowto_STM32_Mandriva.pdf  HowTo_Using_Open_Source_Tools_for_STM32_under_Linux.pdf
get http://www.st.com/stonline/products/literature/rm/      16188.pdf  STM32_RM0041_ReferenceManual_STM32F100xx.pdf
get http://www.st.com/stonline/products/literature/rm/      13902.pdf  STM32_RM0008_ReferenceManual_STM32F100xx.pdf

exit 0
